@@ -1,6 +1,6 @@
 package Algorithm::MedianSelect;
 
-$VERSION = '0.06';
+$VERSION = '0.07';
 @EXPORT_OK = qw(median);
 
 use strict 'vars';
@@ -8,27 +8,27 @@ use base qw(Exporter);
 use Carp 'croak';
 
 sub median {
-    my ($items) = @_;
-    croak 'usage: median( \@items )' unless @$items;
+    my (@items) = @_;
+    croak 'usage: median( @items )' unless @items;
     
-    my $grep = ($items->[0] =~ /\d/) 
-      ? grep /\d/,     @$items
-      : grep /[a-z]/i, @$items;
-    croak "Mixed types aren't supported" if $grep != @$items;    
+    my $grep = ($items[0] =~ /\d/) 
+      ? grep /\d/,     @items
+      : grep /[a-z]/i, @items;
+    croak "Mixed types aren't supported" if $grep != @items;    
     
-    my $mode = ($items->[0] =~ /\d/) ? 'num' : 'char';
+    my $mode = ($items[0] =~ /\d/) ? 'num' : 'char';
         
     croak 'Need odd number of elements'
-      if ($mode eq 'char' && @$items % 2 == 0);
+      if ($mode eq 'char' && @items % 2 == 0);
       
-    my $i = @$items / 2;
+    my $i = @items / 2;
         
     if ($mode eq 'num' && length $i == 1) {
-        my @medians = (_sort_num( $items ))[$i-1, $i];
+        my @medians = (_sort_num( \@items ))[$i-1, $i];
 	
 	return ($medians[0] + (($medians[1] - $medians[0]) / 2));
     }
-    else { return (&{"_sort_$mode"}( $items ))[int( $i )] }
+    else { return (&{"_sort_$mode"}( \@items ))[int( $i )] }
 }
 
 sub _sort_num { 
@@ -60,7 +60,7 @@ Algorithm::MedianSelect - Median finding algorithm
 
  @num_items = qw(1 2 3 5 6 7 9 12 14 19 21);
 
- print median( \@num_items );
+ print median( @num_items );
 
 =head1 DESCRIPTION
 
@@ -75,7 +75,7 @@ are evaluated by their length. Mixed types are unsupported.
 
 Returns the median item.
 
- $median = median( \@items );
+ $median = median( @items );
 
 =head1 SEE ALSO
 
